@@ -13,7 +13,7 @@ use warnings;
 use utf8;
 package Dist::Zilla::Plugin::Twitter;
 BEGIN {
-  $Dist::Zilla::Plugin::Twitter::VERSION = '0.006';
+  $Dist::Zilla::Plugin::Twitter::VERSION = '0.007';
 }
 # ABSTRACT: Twitter when you release with Dist::Zilla
 
@@ -42,6 +42,11 @@ has 'tweet_url' => (
   default => 'http://cpan.cpantesters.org/authors/id/{{$AUTHOR_PATH}}/{{$DIST}}-{{$VERSION}}.readme',
 );
 
+has 'hash_tags' => (
+  is  => 'ro',
+  isa => 'Str',
+);
+
 has '_rand_seeds' => (
   is => 'ro',
   isa => 'Str',
@@ -59,7 +64,6 @@ has '_rand_seeds' => (
 END
 );
 
-
 # methods
 
 sub after_release {
@@ -92,6 +96,9 @@ sub after_release {
     $stash->{URL} = WWW::Shorten::TinyURL::makeashorterlink($longurl);
 
     my $msg = $self->fill_in_string( $self->tweet, $stash);
+    if (defined $self->hash_tags) {
+        $msg .= " " . $self->hash_tags;
+    }
 
     my ($l,$p) = Net::Netrc->lookup('api.twitter.com')->lpa;
     my $nt = Net::Twitter->new(
@@ -126,13 +133,14 @@ Dist::Zilla::Plugin::Twitter - Twitter when you release with Dist::Zilla
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
 In your C<<< dist.ini >>>:
 
    [Twitter]
+   hash_tags = #foo
 
 In your C<<< .netrc >>>:
 
@@ -168,6 +176,12 @@ available for substitution in the URL and message templates:
 You must be using the C<<< UploadToCPAN >>> plugin for this plugin to
 determine your CPAN author ID.
 
+You can use the C<<< hash_tags >>> option to append hash tags (or anything,
+really) to the end of the message generated from C<<< tweet >>>.
+
+   [Twitter]
+   hash-tags = #perl #cpan #foo
+
 =for Pod::Coverage after_release
 
 =head1 AUTHOR
